pub struct SuperAdminAuth(pub AuthClaims);Expand description
Extractor that requires the caller to be a super admin (Admin role with
empty allowed_contexts).
Use on endpoints that only unrestricted administrators should access, such as creating/deleting contexts or modifying global configuration:
ⓘ
async fn handler(auth: SuperAdminAuth, ...) { }Tuple Fields
0: AuthClaimsTrait Implementations
Sourceimpl Clone for SuperAdminAuth
impl Clone for SuperAdminAuth
Sourcefn clone(&self) -> SuperAdminAuth
fn clone(&self) -> SuperAdminAuth
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SuperAdminAuth
impl Debug for SuperAdminAuth
Sourceimpl<S: AuthState> FromRequestParts<S> for SuperAdminAuth
impl<S: AuthState> FromRequestParts<S> for SuperAdminAuth