pub struct WriteAuth(pub AuthClaims);Expand description
Extractor that requires the caller to have at least Application role (Admin, Initiator, or Application).
Use on endpoints that perform write operations — signing, cache writes, and other actions that produce artifacts or modify state:
ⓘ
async fn handler(auth: WriteAuth, ...) { }Tuple Fields
0: AuthClaimsTrait Implementations
Sourceimpl<S: AuthState> FromRequestParts<S> for WriteAuth
impl<S: AuthState> FromRequestParts<S> for WriteAuth