JwtKeys

Struct JwtKeys 

pub struct JwtKeys { /* private fields */ }
Holds the JWT encoding and decoding keys derived from an Ed25519 seed.

Implementations

Source

impl JwtKeys

pub fn from_ed25519_bytes( private_bytes: &[u8; 32], audience: &str, ) -> Result<Self, AppError>

Create JWT keys from raw 32-byte Ed25519 private key bytes.

audience is the expected JWT audience claim (e.g., “VTA” or “VTC”).

Computes the public key and wraps both in DER format as required by jsonwebtoken’s from_ed_der() methods.

pub fn encode(&self, claims: &Claims) -> Result<String, AppError>

Encode claims into a signed JWT access token.

pub fn decode(&self, token: &str) -> Result<Claims, AppError>

Decode and validate a JWT access token, returning the claims.

pub fn new_claims( &self, sub: String, session_id: String, role: String, contexts: Vec<String>, expiry_secs: u64, tee_attested: bool, ) -> Claims

Create claims for a new access token.